pub struct Command {
name: String,
arguments: <List as Data>::Type,
response: <MultilineList as Data>::Type,
}Expand description
Abstract representation of a command that may be supported by an engine. Contains the name of the command as well as the argument and result type specifications.
Fields
name: Stringarguments: <List as Data>::Typeresponse: <MultilineList as Data>::TypeTrait Implementations