pub struct Input<'a> {
bytes: &'a [u8],
}Fields
bytes: &'a [u8]Trait Implementations
Sourceimpl<'a> AtEof for Input<'a>
impl<'a> AtEof for Input<'a>
Sourcefn at_eof(&self) -> bool
fn at_eof(&self) -> bool
While it might be possible in some settings to determine that the connection has closed and no further data may arrive, it is quite irrelevant considering the particular syntax of GTP. The only use case would be determining malformed input which ends without proper termination but this is currently beyond the scope of this implementation.
Sourceimpl<'a, S> Compare<S> for Input<'a>
impl<'a, S> Compare<S> for Input<'a>
Sourcefn compare(&self, t: S) -> CompareResult
fn compare(&self, t: S) -> CompareResult
compares self to another value for equality
Sourcefn compare_no_case(&self, t: S) -> CompareResult
fn compare_no_case(&self, t: S) -> CompareResult
compares self to another value for equality
independently of the case. Read more
Sourceimpl<'a> InputIter for Input<'a>
impl<'a> InputIter for Input<'a>
type Item = u8
type RawItem = u8
type Iter = Enumerator<'a>
type IterElem = Iterator<'a>
Sourcefn iter_indices(&self) -> Self::Iter
fn iter_indices(&self) -> Self::Iter
returns an iterator over the elements and their byte offsets
Sourcefn iter_elements(&self) -> Self::IterElem
fn iter_elements(&self) -> Self::IterElem
returns an iterator over the elements
Sourceimpl<'a> InputLength for Input<'a>
impl<'a> InputLength for Input<'a>
impl<'a> ParseTo for Input<'a>
impl<'a> Slice for Input<'a>
impl<'a> UnspecializedInput for Input<'a>
This allows us to use a default implementation
for InputTakeAtPosition.