macro_rules! command {
($name:expr => ($($args:tt)*) -> ($($resp:tt)*)) => { ... };
}Expand description
Specify a new command.
The macro takes three arguments, separated by semicola.
The first is the name of the command, e.g. as string constant,
the other two are the type specification
of the arguments and the response, respectively.
The syntax for specfication of types is not final
and due to restrictions of Rusts macro system
(There appears to be no way to let * be a part of the macros syntax
since it is part of the macro_rules! syntax.)
not exactly as in the spec.